vector

package module
v0.1.1-0...-dcc004d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 9, 2023 License: MIT Imports: 0 Imported by: 0

README

vector

A simple package written in Go that helps working with vectors

Usage

Create a vector

a := Vector(1, 1, 1)

Installation

Warning You need Go to be installed

To install vector run following command in your terminal

go get github.com/Antonov-Artem/vector

Documentation

Overview

Vector

This is a simple package for working with 3D vectors

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Vector

func Vector(x float64, y float64, z float64) vector64

Initializes 3D vector

Types

This section is empty.

Jump to